@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -56,8 +56,8 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
             try {
                 String jdbc4ClassName = Util.isJdbc42() ? "com.mysql.jdbc.jdbc2.optional.JDBC42PreparedStatementWrapper"
                         : "com.mysql.jdbc.jdbc2.optional.JDBC4PreparedStatementWrapper";
-                JDBC_4_PREPARED_STATEMENT_WRAPPER_CTOR = Class.forName(jdbc4ClassName).getConstructor(
-                        new Class[] { ConnectionWrapper.class, MysqlPooledConnection.class, PreparedStatement.class });
+                JDBC_4_PREPARED_STATEMENT_WRAPPER_CTOR = Class.forName(jdbc4ClassName)
+                        .getConstructor(new Class[] { ConnectionWrapper.class, MysqlPooledConnection.class, PreparedStatement.class });
             } catch (SecurityException e) {
                 throw new RuntimeException(e);
             } catch (NoSuchMethodException e) {
@@ -83,11 +83,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         super(c, conn, toWrap);
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setArray(int, java.sql.Array)
-     */
     public void setArray(int parameterIndex, Array x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -100,11 +95,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setAsciiStream(int, java.io.InputStream, int)
-     */
     public void setAsciiStream(int parameterIndex, InputStream x, int length) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -117,11 +107,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setBigDecimal(int, java.math.BigDecimal)
-     */
     public void setBigDecimal(int parameterIndex, BigDecimal x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -134,11 +119,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setBinaryStream(int, java.io.InputStream, int)
-     */
     public void setBinaryStream(int parameterIndex, InputStream x, int length) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -151,11 +131,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setBlob(int, java.sql.Blob)
-     */
     public void setBlob(int parameterIndex, Blob x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -168,11 +143,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setBoolean(int, boolean)
-     */
     public void setBoolean(int parameterIndex, boolean x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -185,11 +155,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setByte(int, byte)
-     */
     public void setByte(int parameterIndex, byte x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -202,11 +167,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setBytes(int, byte[])
-     */
     public void setBytes(int parameterIndex, byte[] x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -219,11 +179,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setCharacterStream(int, java.io.Reader, int)
-     */
     public void setCharacterStream(int parameterIndex, Reader reader, int length) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -236,11 +191,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setClob(int, java.sql.Clob)
-     */
     public void setClob(int parameterIndex, Clob x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -253,11 +203,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setDate(int, java.sql.Date)
-     */
     public void setDate(int parameterIndex, Date x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -270,11 +215,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setDate(int, java.sql.Date, java.util.Calendar)
-     */
     public void setDate(int parameterIndex, Date x, Calendar cal) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -287,11 +227,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setDouble(int, double)
-     */
     public void setDouble(int parameterIndex, double x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -304,11 +239,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setFloat(int, float)
-     */
     public void setFloat(int parameterIndex, float x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -321,11 +251,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setInt(int, int)
-     */
     public void setInt(int parameterIndex, int x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -338,11 +263,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setLong(int, long)
-     */
     public void setLong(int parameterIndex, long x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -355,11 +275,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#getMetaData()
-     */
     public ResultSetMetaData getMetaData() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -374,11 +289,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         return null;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setNull(int, int)
-     */
     public void setNull(int parameterIndex, int sqlType) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -391,11 +301,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setNull(int, int, java.lang.String)
-     */
     public void setNull(int parameterIndex, int sqlType, String typeName) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -408,11 +313,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setObject(int, java.lang.Object)
-     */
     public void setObject(int parameterIndex, Object x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -425,11 +325,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setObject(int, java.lang.Object, int)
-     */
     public void setObject(int parameterIndex, Object x, int targetSqlType) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -442,11 +337,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setObject(int, java.lang.Object, int, int)
-     */
     public void setObject(int parameterIndex, Object x, int targetSqlType, int scale) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -459,11 +349,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#getParameterMetaData()
-     */
     public ParameterMetaData getParameterMetaData() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -478,11 +363,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         return null;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setRef(int, java.sql.Ref)
-     */
     public void setRef(int parameterIndex, Ref x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -495,11 +375,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setShort(int, short)
-     */
     public void setShort(int parameterIndex, short x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -512,11 +387,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setString(int, java.lang.String)
-     */
     public void setString(int parameterIndex, String x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -529,11 +399,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setTime(int, java.sql.Time)
-     */
     public void setTime(int parameterIndex, Time x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -546,11 +411,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setTime(int, java.sql.Time, java.util.Calendar)
-     */
     public void setTime(int parameterIndex, Time x, Calendar cal) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -563,11 +423,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setTimestamp(int, java.sql.Timestamp)
-     */
     public void setTimestamp(int parameterIndex, Timestamp x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -580,11 +435,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setTimestamp(int, java.sql.Timestamp, java.util.Calendar)
-     */
     public void setTimestamp(int parameterIndex, Timestamp x, Calendar cal) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -597,11 +447,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#setURL(int, java.net.URL)
-     */
     public void setURL(int parameterIndex, URL x) throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -637,11 +482,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#addBatch()
-     */
     public void addBatch() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -654,11 +494,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#clearParameters()
-     */
     public void clearParameters() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -671,11 +506,6 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#execute()
-     */
     public boolean execute() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
@@ -690,34 +520,23 @@ public class PreparedStatementWrapper extends StatementWrapper implements Prepar
         return false; // we actually never get here, but the compiler can't figure that out
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#executeQuery()
-     */
     public ResultSet executeQuery() throws SQLException {
+
+        ResultSet rs = null;
         try {
-            if (this.wrappedStmt != null) {
-                ResultSet rs = ((PreparedStatement) this.wrappedStmt).executeQuery();
-
-                ((com.mysql.jdbc.ResultSetInternalMethods) rs).setWrapperStatement(this);
-
-                return rs;
+            if (this.wrappedStmt == null) {
+                throw SQLError.createSQLException("No operations allowed after statement closed", SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
             }
+            rs = ((PreparedStatement) this.wrappedStmt).executeQuery();
+            ((com.mysql.jdbc.ResultSetInternalMethods) rs).setWrapperStatement(this);
 
-            throw SQLError.createSQLException("No operations allowed after statement closed", SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
         } catch (SQLException sqlEx) {
             checkAndFireConnectionError(sqlEx);
         }
 
-        return null; // we actually never get here, but the compiler can't figure that out
+        return rs;
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see java.sql.PreparedStatement#executeUpdate()
-     */
     public int executeUpdate() throws SQLException {
         try {
             if (this.wrappedStmt != null) {
